![Coverage](.badges/coverage.svg)
# Differentiable RHEED simulations in JAX

The aim of this project is to write RHEED simulations in [JAX](https://github.com/google/jax) so that it's end to end differentiable.

This will install the package as `rheedium`, which is the package that all the codes are.

The codes themselves are in the _src_ directory, following the modern toml convention as the _rheedium_ folder.